# libpythonpro

Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Build Status](https://app.travis-ci.com/HenriqueCCdA/libpythonpro.svg?branch=main)](https://app.travis-ci.com/HenriqueCCdA/libpythonpro)
[![Updates](https://pyup.io/repos/github/HenriqueCCdA/libpythonpro/shield.svg)](https://pyup.io/repos/github/HenriqueCCdA/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/HenriqueCCdA/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/HenriqueCCdA/libpythonpro/)
<!---
[![codecov](https://codecov.io/gh/pythonprobr/libpythonpro/branch/master/graph/badge.svg)](https://codecov.io/gh/pythonprobr/libpythonpro)
-->

Suportada versão 3 de Python

Para instalar:

```console
pip install pipenv
pipenv install --dev
```

Para conferir qualidade de código:

```console
pipenv run flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
4. Mock
5. Pipenv